Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(947)

Unified Diff: chrome/browser/ui/webui/print_preview/print_preview_handler.h

Issue 1153173002: Include USB printers in printer list as "provisional" devices. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/print_preview/print_preview_handler.h
diff --git a/chrome/browser/ui/webui/print_preview/print_preview_handler.h b/chrome/browser/ui/webui/print_preview/print_preview_handler.h
index 5240f9e88927ce09c67131438692af8e32ecf551..356678bed9cdcfc9340d98f5e06ebf06e64f4629 100644
--- a/chrome/browser/ui/webui/print_preview/print_preview_handler.h
+++ b/chrome/browser/ui/webui/print_preview/print_preview_handler.h
@@ -21,6 +21,7 @@
#include "chrome/browser/local_discovery/service_discovery_shared_client.h"
#endif // ENABLE_SERVICE_DISCOVERY
+class ExtensionPrinterHandler;
class PrinterHandler;
class PrintPreviewUI;
class PrintSystemTaskProxy;
@@ -122,12 +123,16 @@ class PrintPreviewHandler
// Gets the list of printers. |args| is unused.
void HandleGetPrinters(const base::ListValue* args);
// Starts getting all local privet printers. |arg| is unused.
void HandleGetPrivetPrinters(const base::ListValue* args);
// Starts getting all local extension managed printers. |arg| is unused.
void HandleGetExtensionPrinters(const base::ListValue* args);
+ // Starts getting all local USB printers supported by extensions. |args| is
+ // unused.
+ void HandleGetExtensionUsbPrinters(const base::ListValue* args);
+
// Stops getting all local privet printers. |arg| is unused.
void HandleStopGetPrivetPrinters(const base::ListValue* args);
@@ -308,6 +313,10 @@ class PrintPreviewHandler
// they manage.
void OnGotPrintersForExtension(const base::ListValue& printers, bool done);
+ // Called with the list of USB printers supported by extensions.
+ // |printers|: The list of printers supported by extensions.
+ void OnGotExtensionUsbPrinters(const base::ListValue& printers);
+
// Called when an extension reports the set of print capabilites for a
// printer.
// |printer_id|: The id of the printer whose capabilities are reported.
@@ -372,7 +381,7 @@ class PrintPreviewHandler
// Handles requests for extension printers. Created lazily by calling
// |EnsureExtensionPrinterHandlerSet|.
- scoped_ptr<PrinterHandler> extension_printer_handler_;
+ scoped_ptr<ExtensionPrinterHandler> extension_printer_handler_;
Vitaly Buka (NO REVIEWS) 2015/05/27 16:58:40 Idea was to have common interface for different pr
Reilly Grant (use Gerrit) 2015/05/28 21:45:00 Done.
// Notifies tests that want to know if the PDF has been saved. This doesn't
@@ -122,12 +123,16 @@ class PrintPreviewHandler
// Gets the list of printers. |args| is unused.
void HandleGetPrinters(const base::ListValue* args);
- // Starts getting all local privet printers. |arg| is unused.
+ // Starts getting all local privet printers. |args| is unused.
void HandleGetPrivetPrinters(const base::ListValue* args);
@@ -122,12 +123,16 @@ class PrintPreviewHandler
void HandleGetPrivetPrinters(const base::ListValue* args);
- // Starts getting all local extension managed printers. |arg| is unused.
+ // Starts getting all local extension managed printers. |args| is unused.
void HandleGetExtensionPrinters(const base::ListValue* args);
// notify the test if it was a successful save, only that it was attempted.

Powered by Google App Engine
This is Rietveld 408576698